<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Account\Actions\CoaAction;
use Litecms\Account\Http\Requests\CoaActionRequest;
use Litecms\Account\Http\Resources\CoaResource;
use Litecms\Account\Models\Coa;

/**
 * Admin web controller class.
 */
class CoaActionController extends BaseController
{

    /**
     * Action controller function for coa.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CoaActionRequest $request, Coa $coa, $action)
    {
        try {
            $request = $request->all();
            $coa = CoaAction::run($action, $coa, $request);

            $data = new CoaResource($coa);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::coa.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/coa/' . $coa->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/coa/' . $coa->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
