<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Account\Http\Requests\CoaActionsRequest;
use Litecms\Account\Actions\CoaActions;

/**
 * Admin web controller class.
 */
class CoaActionsController extends BaseController
{

    /**
     * Action controller function for coa.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CoaActionsRequest $request, $action)
    {
        try {
            $coa = CoaActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::coa.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/coa/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/coa/' . $action))
                ->redirect();
        }
    }
}
