<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Account\Http\Resources\AccountResource;
use Litecms\Account\Http\Resources\AccountsCollection;
use Litecms\Account\Scopes\CoaPublicScope;
use Litecms\Account\Models\Coa;

class CoaPublicController extends BaseController
{

    /**
     * Show coa's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Coa::pushScope(new RequestScope())
            ->pushScope(new CoaPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $coas = new CoasCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('account::coa.names'))
            ->view('account::public.coa.index')
            ->data(compact('coas', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show coa.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Coa::findBySlug($slug);
        $data = new CoaResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('account::coa.name'))
            ->view('account::public.coa.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
