<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Account\Actions\InvoiceAction;
use Litecms\Account\Http\Requests\InvoiceActionRequest;
use Litecms\Account\Http\Resources\InvoiceResource;
use Litecms\Account\Models\Invoice;

/**
 * Admin web controller class.
 */
class InvoiceActionController extends BaseController
{

    /**
     * Action controller function for invoice.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InvoiceActionRequest $request, Invoice $invoice, $action)
    {
        try {
            $request = $request->all();
            $invoice = InvoiceAction::run($action, $invoice, $request);

            $data = new InvoiceResource($invoice);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::invoice.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/invoice/' . $invoice->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/invoice/' . $invoice->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
