<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Account\Http\Requests\InvoiceActionsRequest;
use Litecms\Account\Actions\InvoiceActions;

/**
 * Admin web controller class.
 */
class InvoiceActionsController extends BaseController
{

    /**
     * Action controller function for invoice.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InvoiceActionsRequest $request, $action)
    {
        try {
            $invoice = InvoiceActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::invoice.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/invoice/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/invoice/' . $action))
                ->redirect();
        }
    }
}
