<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Account\Actions\InvoiceItemsAction;
use Litecms\Account\Http\Requests\InvoiceItemsActionRequest;
use Litecms\Account\Http\Resources\InvoiceItemsResource;
use Litecms\Account\Models\InvoiceItems;

/**
 * Admin web controller class.
 */
class InvoiceItemsActionController extends BaseController
{

    /**
     * Action controller function for invoice_items.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InvoiceItemsActionRequest $request, InvoiceItems $invoice_items, $action)
    {
        try {
            $request = $request->all();
            $invoice_items = InvoiceItemsAction::run($action, $invoice_items, $request);

            $data = new InvoiceItemsResource($invoice_items);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::invoice_items.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/invoice_items/' . $invoice_items->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/invoice_items/' . $invoice_items->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
