<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Account\Http\Requests\InvoiceItemsActionsRequest;
use Litecms\Account\Actions\InvoiceItemsActions;

/**
 * Admin web controller class.
 */
class InvoiceItemsActionsController extends BaseController
{

    /**
     * Action controller function for invoice_items.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InvoiceItemsActionsRequest $request, $action)
    {
        try {
            $invoice_items = InvoiceItemsActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::invoice_items.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/invoice_items/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/invoice_items/' . $action))
                ->redirect();
        }
    }
}
