<?php

namespace Litecms\Account\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litecms\Account\Forms\InvoiceItems as InvoiceItemsForm;
use Litecms\Account\Http\Requests\InvoiceItemsResourceRequest;
use Litecms\Account\Http\Resources\InvoiceItemsResource;
use Litecms\Account\Http\Resources\InvoiceItemsCollection;
use Litecms\Account\Models\InvoiceItems;
use Litecms\Account\Actions\InvoiceItemsAction;
use Litecms\Account\Actions\InvoiceItemsActions;


/**
 * Resource controller class for invoice_items.
 */
class InvoiceItemsResourceController extends BaseController
{

    /**
     * Initialize invoice_items resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = InvoiceItemsForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('litecms.account.modules'), 'account', guard_url('account'));
            return $next($request);
        });
    }

    /**
     * Display a list of invoice_items.
     *
     * @return Response
     */
    public function index(InvoiceItemsResourceRequest $request)
    {
        $request = $request->all();
        $page = InvoiceItemsActions::run('paginate', $request);

        $data = new InvoiceItemsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('account::invoice_items.names'))
            ->view('account::invoice_items.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display invoice_items.
     *
     * @param Request $request
     * @param Model   $invoice_items
     *
     * @return Response
     */
    public function show(InvoiceItemsResourceRequest $request, InvoiceItems $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new InvoiceItemsResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('account::invoice_items.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('account::invoice_items.show')
            ->output();
    }

    /**
     * Show the form for creating a new invoice_items.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(InvoiceItemsResourceRequest $request, InvoiceItems $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new InvoiceItemsResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('account::invoice_items.name'))
            ->view('account::invoice_items.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new invoice_items.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(InvoiceItemsResourceRequest $request, InvoiceItems $model)
    {
        try {
            $request = $request->all();
            $model = InvoiceItemsAction::run('store', $model, $request);
            $data = new InvoiceItemsResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('account::invoice_items.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/invoice_items/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/account/invoice_items'))
                ->redirect();
        }

    }

    /**
     * Show invoice_items for editing.
     *
     * @param Request $request
     * @param Model   $invoice_items
     *
     * @return Response
     */
    public function edit(InvoiceItemsResourceRequest $request, InvoiceItems $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new InvoiceItemsResource($model);
        // return view('account::invoice_items.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('account::invoice_items.name'))
            ->view('account::invoice_items.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the invoice_items.
     *
     * @param Request $request
     * @param Model   $invoice_items
     *
     * @return Response
     */
    public function update(InvoiceItemsResourceRequest $request, InvoiceItems $model)
    {
        try {
            $request = $request->all();
            $model = InvoiceItemsAction::run('update', $model, $request);
            $data = new InvoiceItemsResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::invoice_items.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('account/invoice_items/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/invoice_items/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the invoice_items.
     *
     * @param Model   $invoice_items
     *
     * @return Response
     */
    public function destroy(InvoiceItemsResourceRequest $request, InvoiceItems $model)
    {
        try {

            $request = $request->all();
            $model = InvoiceItemsAction::run('destroy', $model, $request);
            $data = new InvoiceItemsResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('account::invoice_items.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('account/invoice_items/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/invoice_items/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
