<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Account\Http\Resources\AccountResource;
use Litecms\Account\Http\Resources\AccountsCollection;
use Litecms\Account\Scopes\InvoicePublicScope;
use Litecms\Account\Models\Invoice;

class InvoicePublicController extends BaseController
{

    /**
     * Show invoice's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Invoice::pushScope(new RequestScope())
            ->pushScope(new InvoicePublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $invoices = new InvoicesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('account::invoice.names'))
            ->view('account::public.invoice.index')
            ->data(compact('invoices', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show invoice.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Invoice::findBySlug($slug);
        $data = new InvoiceResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('account::invoice.name'))
            ->view('account::public.invoice.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
