<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Account\Actions\InvoiceReport;
use Litecms\Account\Http\Requests\InvoiceReportRequest;

/**
 * Admin web controller class.
 */
class InvoiceReportController extends BaseController
{
    /**
     * Action controller function for invoice.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InvoiceReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Invoice::class);
            $data = InvoiceReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::invoice.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/invoice/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/invoice/' . $report))
                ->redirect();
        }
    }
}
