<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Account\Actions\LedgerAction;
use Litecms\Account\Http\Requests\LedgerActionRequest;
use Litecms\Account\Http\Resources\LedgerResource;
use Litecms\Account\Models\Ledger;

/**
 * Admin web controller class.
 */
class LedgerActionController extends BaseController
{

    /**
     * Action controller function for ledger.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LedgerActionRequest $request, Ledger $ledger, $action)
    {
        try {
            $request = $request->all();
            $ledger = LedgerAction::run($action, $ledger, $request);

            $data = new LedgerResource($ledger);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::ledger.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/ledger/' . $ledger->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/ledger/' . $ledger->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
