<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Account\Http\Requests\LedgerActionsRequest;
use Litecms\Account\Actions\LedgerActions;

/**
 * Admin web controller class.
 */
class LedgerActionsController extends BaseController
{

    /**
     * Action controller function for ledger.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LedgerActionsRequest $request, $action)
    {
        try {
            $ledger = LedgerActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::ledger.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/ledger/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/ledger/' . $action))
                ->redirect();
        }
    }
}
