<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Account\Http\Resources\AccountResource;
use Litecms\Account\Http\Resources\AccountsCollection;
use Litecms\Account\Scopes\LedgerPublicScope;
use Litecms\Account\Models\Ledger;

class LedgerPublicController extends BaseController
{

    /**
     * Show ledger's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Ledger::pushScope(new RequestScope())
            ->pushScope(new LedgerPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $ledgers = new LedgersCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('account::ledger.names'))
            ->view('account::public.ledger.index')
            ->data(compact('ledgers', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show ledger.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Ledger::findBySlug($slug);
        $data = new LedgerResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('account::ledger.name'))
            ->view('account::public.ledger.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
