<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Account\Actions\LedgerReport;
use Litecms\Account\Http\Requests\LedgerReportRequest;

/**
 * Admin web controller class.
 */
class LedgerReportController extends BaseController
{
    /**
     * Action controller function for ledger.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LedgerReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Ledger::class);
            $data = LedgerReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('account::ledger.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/ledger/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/ledger/' . $report))
                ->redirect();
        }
    }
}
