<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Account\Actions\ReceiptAction;
use Litecms\Account\Http\Requests\ReceiptActionRequest;
use Litecms\Account\Http\Resources\ReceiptResource;
use Litecms\Account\Models\Receipt;

/**
 * Admin web controller class.
 */
class ReceiptActionController extends BaseController
{

    /**
     * Action controller function for receipt.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ReceiptActionRequest $request, Receipt $receipt, $action)
    {
        try {
            $request = $request->all();
            $receipt = ReceiptAction::run($action, $receipt, $request);

            $data = new ReceiptResource($receipt);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('account::receipt.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('account/receipt/' . $receipt->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('account/receipt/' . $receipt->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
