<?php

namespace Litecms\Account\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Account\Http\Resources\AccountResource;
use Litecms\Account\Http\Resources\AccountsCollection;
use Litecms\Account\Scopes\ReceiptPublicScope;
use Litecms\Account\Models\Receipt;

class ReceiptPublicController extends BaseController
{

    /**
     * Show receipt's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Receipt::pushScope(new RequestScope())
            ->pushScope(new ReceiptPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $receipts = new ReceiptsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('account::receipt.names'))
            ->view('account::public.receipt.index')
            ->data(compact('receipts', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show receipt.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Receipt::findBySlug($slug);
        $data = new ReceiptResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('account::receipt.name'))
            ->view('account::public.receipt.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
