<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\CoaAction as CoaActionEvent;
use Litecms\Account\Notifications\CoaAction as CoaActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CoaAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CoaActionEvent.
     *
     * @param   CoaActionEvent  $event
     * @return mixed
     */
    public function handle(CoaActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $coa.
     *
     * @param   CoaActionEvent  $event
     * @return void
     */
    public function create(CoaActionEvent $event)
    {
        $client = $event->coa->client;
        Notification::send($client, new CoaActionNotification($event));
    }

    /**
     * Handle the CoaActionEvent as a listener.
     *
     * @param   CoaActionEvent  $event
     * @return mixed
     */
    public function asListener(CoaActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CoaActionEvent  $event
     * @return bool
     */
    private function isAllowed(CoaActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
