<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\CoaWorkflow as CoaWorkflowEvent;
use Litecms\Account\Notifications\CoaWorkflow as CoaWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class CoaWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(CoaWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $coa is submitted.
     *
     * @param CoaWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(CoaWorkflowEvent $event)
    {
        $client = $event->coa->client;
        Notification::send($client, new CoaWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $coa is published.
     *
     * @param CoaWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(CoaWorkflowEvent $event)
    {
        $client = $event->coa->client;
        Notification::send($client, new CoaWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $coa is approved.
     *
     * @param CoaWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(CoaWorkflowEvent $event)
    {
        $client = $event->coa->client;
        Notification::send($client, new CoaWorkflowNotification($event));
    }

    /**
     * Handles the $coa workflow event as a listener.
     *
     * @param CoaWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(CoaWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
