<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\CostcenterAction as CostcenterActionEvent;
use Litecms\Account\Notifications\CostcenterAction as CostcenterActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CostcenterAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CostcenterActionEvent.
     *
     * @param   CostcenterActionEvent  $event
     * @return mixed
     */
    public function handle(CostcenterActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $costcenter.
     *
     * @param   CostcenterActionEvent  $event
     * @return void
     */
    public function create(CostcenterActionEvent $event)
    {
        $client = $event->costcenter->client;
        Notification::send($client, new CostcenterActionNotification($event));
    }

    /**
     * Handle the CostcenterActionEvent as a listener.
     *
     * @param   CostcenterActionEvent  $event
     * @return mixed
     */
    public function asListener(CostcenterActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CostcenterActionEvent  $event
     * @return bool
     */
    private function isAllowed(CostcenterActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
