<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\CostcenterWorkflow as CostcenterWorkflowEvent;
use Litecms\Account\Notifications\CostcenterWorkflow as CostcenterWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class CostcenterWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(CostcenterWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $costcenter is submitted.
     *
     * @param CostcenterWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(CostcenterWorkflowEvent $event)
    {
        $client = $event->costcenter->client;
        Notification::send($client, new CostcenterWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $costcenter is published.
     *
     * @param CostcenterWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(CostcenterWorkflowEvent $event)
    {
        $client = $event->costcenter->client;
        Notification::send($client, new CostcenterWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $costcenter is approved.
     *
     * @param CostcenterWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(CostcenterWorkflowEvent $event)
    {
        $client = $event->costcenter->client;
        Notification::send($client, new CostcenterWorkflowNotification($event));
    }

    /**
     * Handles the $costcenter workflow event as a listener.
     *
     * @param CostcenterWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(CostcenterWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
