<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\InvoiceItemsAction as InvoiceItemsActionEvent;
use Litecms\Account\Notifications\InvoiceItemsAction as InvoiceItemsActionNotification;
use Litepie\Actions\Concerns\AsAction;

class InvoiceItemsAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the InvoiceItemsActionEvent.
     *
     * @param   InvoiceItemsActionEvent  $event
     * @return mixed
     */
    public function handle(InvoiceItemsActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $invoice_items.
     *
     * @param   InvoiceItemsActionEvent  $event
     * @return void
     */
    public function create(InvoiceItemsActionEvent $event)
    {
        $client = $event->invoice_items->client;
        Notification::send($client, new InvoiceItemsActionNotification($event));
    }

    /**
     * Handle the InvoiceItemsActionEvent as a listener.
     *
     * @param   InvoiceItemsActionEvent  $event
     * @return mixed
     */
    public function asListener(InvoiceItemsActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   InvoiceItemsActionEvent  $event
     * @return bool
     */
    private function isAllowed(InvoiceItemsActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
