<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\JournalAction as JournalActionEvent;
use Litecms\Account\Notifications\JournalAction as JournalActionNotification;
use Litepie\Actions\Concerns\AsAction;

class JournalAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the JournalActionEvent.
     *
     * @param   JournalActionEvent  $event
     * @return mixed
     */
    public function handle(JournalActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $journal.
     *
     * @param   JournalActionEvent  $event
     * @return void
     */
    public function create(JournalActionEvent $event)
    {
        $client = $event->journal->client;
        Notification::send($client, new JournalActionNotification($event));
    }

    /**
     * Handle the JournalActionEvent as a listener.
     *
     * @param   JournalActionEvent  $event
     * @return mixed
     */
    public function asListener(JournalActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   JournalActionEvent  $event
     * @return bool
     */
    private function isAllowed(JournalActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
