<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\JournalWorkflow as JournalWorkflowEvent;
use Litecms\Account\Notifications\JournalWorkflow as JournalWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class JournalWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(JournalWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $journal is submitted.
     *
     * @param JournalWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(JournalWorkflowEvent $event)
    {
        $client = $event->journal->client;
        Notification::send($client, new JournalWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $journal is published.
     *
     * @param JournalWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(JournalWorkflowEvent $event)
    {
        $client = $event->journal->client;
        Notification::send($client, new JournalWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $journal is approved.
     *
     * @param JournalWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(JournalWorkflowEvent $event)
    {
        $client = $event->journal->client;
        Notification::send($client, new JournalWorkflowNotification($event));
    }

    /**
     * Handles the $journal workflow event as a listener.
     *
     * @param JournalWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(JournalWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
