<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\LedgerAction as LedgerActionEvent;
use Litecms\Account\Notifications\LedgerAction as LedgerActionNotification;
use Litepie\Actions\Concerns\AsAction;

class LedgerAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the LedgerActionEvent.
     *
     * @param   LedgerActionEvent  $event
     * @return mixed
     */
    public function handle(LedgerActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $ledger.
     *
     * @param   LedgerActionEvent  $event
     * @return void
     */
    public function create(LedgerActionEvent $event)
    {
        $client = $event->ledger->client;
        Notification::send($client, new LedgerActionNotification($event));
    }

    /**
     * Handle the LedgerActionEvent as a listener.
     *
     * @param   LedgerActionEvent  $event
     * @return mixed
     */
    public function asListener(LedgerActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   LedgerActionEvent  $event
     * @return bool
     */
    private function isAllowed(LedgerActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
