<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\LedgerWorkflow as LedgerWorkflowEvent;
use Litecms\Account\Notifications\LedgerWorkflow as LedgerWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class LedgerWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(LedgerWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $ledger is submitted.
     *
     * @param LedgerWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(LedgerWorkflowEvent $event)
    {
        $client = $event->ledger->client;
        Notification::send($client, new LedgerWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $ledger is published.
     *
     * @param LedgerWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(LedgerWorkflowEvent $event)
    {
        $client = $event->ledger->client;
        Notification::send($client, new LedgerWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $ledger is approved.
     *
     * @param LedgerWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(LedgerWorkflowEvent $event)
    {
        $client = $event->ledger->client;
        Notification::send($client, new LedgerWorkflowNotification($event));
    }

    /**
     * Handles the $ledger workflow event as a listener.
     *
     * @param LedgerWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(LedgerWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
