<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\ReceiptAction as ReceiptActionEvent;
use Litecms\Account\Notifications\ReceiptAction as ReceiptActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ReceiptAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ReceiptActionEvent.
     *
     * @param   ReceiptActionEvent  $event
     * @return mixed
     */
    public function handle(ReceiptActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $receipt.
     *
     * @param   ReceiptActionEvent  $event
     * @return void
     */
    public function create(ReceiptActionEvent $event)
    {
        $client = $event->receipt->client;
        Notification::send($client, new ReceiptActionNotification($event));
    }

    /**
     * Handle the ReceiptActionEvent as a listener.
     *
     * @param   ReceiptActionEvent  $event
     * @return mixed
     */
    public function asListener(ReceiptActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ReceiptActionEvent  $event
     * @return bool
     */
    private function isAllowed(ReceiptActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
