<?php

namespace Litecms\Account\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Account\Events\ReceiptWorkflow as ReceiptWorkflowEvent;
use Litecms\Account\Notifications\ReceiptWorkflow as ReceiptWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ReceiptWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ReceiptWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $receipt is submitted.
     *
     * @param ReceiptWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ReceiptWorkflowEvent $event)
    {
        $client = $event->receipt->client;
        Notification::send($client, new ReceiptWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $receipt is published.
     *
     * @param ReceiptWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ReceiptWorkflowEvent $event)
    {
        $client = $event->receipt->client;
        Notification::send($client, new ReceiptWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $receipt is approved.
     *
     * @param ReceiptWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ReceiptWorkflowEvent $event)
    {
        $client = $event->receipt->client;
        Notification::send($client, new ReceiptWorkflowNotification($event));
    }

    /**
     * Handles the $receipt workflow event as a listener.
     *
     * @param ReceiptWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ReceiptWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
