<?php
namespace Litecms\Account\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Account\Events\CoaAction as CoaActionEvent;
use Litecms\Account\Models\Coa;

class CoaAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $coa;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param CoaActionEvent $coa
     */
    public function __construct(CoaActionEvent $coa)
    {
        $this->action = $event->action;
        $this->coa = $coa;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Coa Approved - ' . config('app.name'))
            ->view('account::coa.email.action', ['data' => $this->coa]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
