<?php
namespace Litecms\Account\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Account\Events\InvoiceItemsAction as InvoiceItemsActionEvent;
use Litecms\Account\Models\InvoiceItems;

class InvoiceItemsAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $invoice_items;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param InvoiceItemsActionEvent $invoice_items
     */
    public function __construct(InvoiceItemsActionEvent $invoice_items)
    {
        $this->action = $event->action;
        $this->invoice_items = $invoice_items;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('InvoiceItems Approved - ' . config('app.name'))
            ->view('account::invoice_items.email.action', ['data' => $this->invoice_items]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
