<?php
namespace Litecms\Account\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Account\Events\LedgerAction as LedgerActionEvent;
use Litecms\Account\Models\Ledger;

class LedgerAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $ledger;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param LedgerActionEvent $ledger
     */
    public function __construct(LedgerActionEvent $ledger)
    {
        $this->action = $event->action;
        $this->ledger = $ledger;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Ledger Approved - ' . config('app.name'))
            ->view('account::ledger.email.action', ['data' => $this->ledger]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
