<?php
namespace Litecms\Account\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Account\Events\ReceiptAction as ReceiptActionEvent;
use Litecms\Account\Models\Receipt;

class ReceiptAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $receipt;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ReceiptActionEvent $receipt
     */
    public function __construct(ReceiptActionEvent $receipt)
    {
        $this->action = $event->action;
        $this->receipt = $receipt;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Receipt Approved - ' . config('app.name'))
            ->view('account::receipt.email.action', ['data' => $this->receipt]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
