<?php

namespace Litecms\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Account\Models\Coa;

class CoaPolicy
{

    use CoaAction;

    /**
     * Determine if the given user can view the coa.
     *
     * @param Authenticatable $user
     * @param Coa $coa
     *
     * @return bool
     */
    public function view(Authenticatable $user, Coa $coa)
    {
        if ($authUser->canDo('account.coa.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $coa->is_owner;
    }

    /**
     * Determine if the given user can create a coa.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.coa.create');
    }

    /**
     * Determine if the given user can update the given coa.
     *
     * @param Authenticatable $user
     * @param Coa $coa
     *
     * @return bool
     */
    public function update(Authenticatable $user, Coa $coa)
    {
        if ($user->canDo('account.coa.edit') && $user->isAdmin()) {
            return true;
        }

        return $coa->is_owner;
    }

    /**
     * Determine if the given user can delete the given coa.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Coa $coa)
    {
        return $coa->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
