<?php

namespace Litecms\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Account\Models\InvoiceItems;

class InvoiceItemsPolicy
{

    use InvoiceItemsAction;

    /**
     * Determine if the given user can view the invoice_items.
     *
     * @param Authenticatable $user
     * @param InvoiceItems $invoice_items
     *
     * @return bool
     */
    public function view(Authenticatable $user, InvoiceItems $invoice_items)
    {
        if ($authUser->canDo('account.invoice_items.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $invoice_items->is_owner;
    }

    /**
     * Determine if the given user can create a invoice_items.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.invoice_items.create');
    }

    /**
     * Determine if the given user can update the given invoice_items.
     *
     * @param Authenticatable $user
     * @param InvoiceItems $invoice_items
     *
     * @return bool
     */
    public function update(Authenticatable $user, InvoiceItems $invoice_items)
    {
        if ($user->canDo('account.invoice_items.edit') && $user->isAdmin()) {
            return true;
        }

        return $invoice_items->is_owner;
    }

    /**
     * Determine if the given user can delete the given invoice_items.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, InvoiceItems $invoice_items)
    {
        return $invoice_items->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
