<?php

namespace Litecms\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Account\Models\Journal;

class JournalPolicy
{


    /**
     * Determine if the given user can view the journal.
     *
     * @param Authenticatable $user
     * @param Journal $journal
     *
     * @return bool
     */
    public function view(Authenticatable $user, Journal $journal)
    {
        if ($authUser->canDo('account.journal.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $journal->is_owner;
    }

    /**
     * Determine if the given user can create a journal.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.journal.create');
    }

    /**
     * Determine if the given user can update the given journal.
     *
     * @param Authenticatable $user
     * @param Journal $journal
     *
     * @return bool
     */
    public function update(Authenticatable $user, Journal $journal)
    {
        if ($user->canDo('account.journal.edit') && $user->isAdmin()) {
            return true;
        }

        return $journal->is_owner;
    }

    /**
     * Determine if the given user can delete the given journal.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Journal $journal)
    {
        return $journal->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
