<?php

namespace Litecms\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Account\Models\Ledger;

class LedgerPolicy
{

    use LedgerAction;
    use LedgerReport;
    use LedgerWorkflow;

    /**
     * Determine if the given user can view the ledger.
     *
     * @param Authenticatable $user
     * @param Ledger $ledger
     *
     * @return bool
     */
    public function view(Authenticatable $user, Ledger $ledger)
    {
        if ($authUser->canDo('account.ledger.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $ledger->is_owner;
    }

    /**
     * Determine if the given user can create a ledger.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.ledger.create');
    }

    /**
     * Determine if the given user can update the given ledger.
     *
     * @param Authenticatable $user
     * @param Ledger $ledger
     *
     * @return bool
     */
    public function update(Authenticatable $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.edit') && $user->isAdmin()) {
            return true;
        }

        return $ledger->is_owner;
    }

    /**
     * Determine if the given user can delete the given ledger.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Ledger $ledger)
    {
        return $ledger->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
