<?php

namespace Litecms\Account\Policies;

use Litecms\Account\Models\Ledger;
use Illuminate\Foundation\Auth\User as Authenticatable;

trait LedgerWorkflow
{

    /**
     * Determine if the given user can approve the given ledger.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function approve(Authenticatable $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ledger.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function submit(Authenticatable $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ledger.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function publish(Authenticatable $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ledger.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unpublish(Authenticatable $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ledger.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function archive(Authenticatable $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ledger.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unarchive(Authenticatable $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ledger.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function reject(Authenticatable $user, Ledger $ledger)
    {
        if ($user->canDo('account.ledger.reject')) {
            return true;
        }

        return false;
    }

}
