<?php

namespace Litecms\Account\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Account\Models\Receipt;

class ReceiptPolicy
{

    use ReceiptAction;
    use ReceiptReport;
    use ReceiptWorkflow;

    /**
     * Determine if the given user can view the receipt.
     *
     * @param Authenticatable $user
     * @param Receipt $receipt
     *
     * @return bool
     */
    public function view(Authenticatable $user, Receipt $receipt)
    {
        if ($authUser->canDo('account.receipt.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $receipt->is_owner;
    }

    /**
     * Determine if the given user can create a receipt.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('account.receipt.create');
    }

    /**
     * Determine if the given user can update the given receipt.
     *
     * @param Authenticatable $user
     * @param Receipt $receipt
     *
     * @return bool
     */
    public function update(Authenticatable $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.edit') && $user->isAdmin()) {
            return true;
        }

        return $receipt->is_owner;
    }

    /**
     * Determine if the given user can delete the given receipt.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Receipt $receipt)
    {
        return $receipt->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
