<?php

namespace Litecms\Account\Policies;

use Litecms\Account\Models\Receipt;
use Illuminate\Foundation\Auth\User as Authenticatable;

trait ReceiptWorkflow
{

    /**
     * Determine if the given user can approve the given receipt.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function approve(Authenticatable $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given receipt.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function submit(Authenticatable $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given receipt.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function publish(Authenticatable $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given receipt.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unpublish(Authenticatable $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given receipt.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function archive(Authenticatable $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given receipt.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unarchive(Authenticatable $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given receipt.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function reject(Authenticatable $user, Receipt $receipt)
    {
        if ($user->canDo('account.receipt.reject')) {
            return true;
        }

        return false;
    }

}
