<?php

namespace Litecms\Account\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\Account\Accounts;

class AccountServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'account');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'account');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Litecms\Account\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Account\Providers\RouteServiceProvider::class);
        $this->app->register(\Litecms\Account\Providers\ActionServiceProvider::class);
        $this->app->register(\Litecms\Account\Providers\EventServiceProvider::class);
        $this->app->register(\Litecms\Account\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.account', function($app)
        {
            return $this->app->make(Account::class);
        });
    }

    /**
     * Merges user's and account's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.account'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/receipt.php', 'litecms.account.receipt'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/invoice.php', 'litecms.account.invoice'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/invoice_items.php', 'litecms.account.invoice_items'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/product.php', 'litecms.account.product'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/coa.php', 'litecms.account.coa'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/costcenter.php', 'litecms.account.costcenter'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/ledger.php', 'litecms.account.ledger'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/journal.php', 'litecms.account.journal'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/detail.php', 'litecms.account.detail'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.account'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('litecms/account')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/account')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/account')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
