<?php

namespace Litecms\Account\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Litecms\Account\Models\Receipt;
use Litecms\Account\Models\Invoice;
use Litecms\Account\Models\InvoiceItems;
use Litecms\Account\Models\Product;
use Litecms\Account\Models\Coa;
use Litecms\Account\Models\Costcenter;
use Litecms\Account\Models\Ledger;
use Litecms\Account\Models\Journal;
use Litecms\Account\Models\Detail;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\Account\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/account/receipt/*')) {
            Route::bind('receipt', function ($receipt) {
                return Receipt::findorNew($receipt);
            });
        }
        if (Request::is('*/account/invoice/*')) {
            Route::bind('invoice', function ($invoice) {
                return Invoice::findorNew($invoice);
            });
        }
        if (Request::is('*/account/invoice_items/*')) {
            Route::bind('invoice_items', function ($invoice_items) {
                return InvoiceItems::findorNew($invoice_items);
            });
        }
        if (Request::is('*/account/product/*')) {
            Route::bind('product', function ($product) {
                return Product::findorNew($product);
            });
        }
        if (Request::is('*/account/coa/*')) {
            Route::bind('coa', function ($coa) {
                return Coa::findorNew($coa);
            });
        }
        if (Request::is('*/account/costcenter/*')) {
            Route::bind('costcenter', function ($costcenter) {
                return Costcenter::findorNew($costcenter);
            });
        }
        if (Request::is('*/account/ledger/*')) {
            Route::bind('ledger', function ($ledger) {
                return Ledger::findorNew($ledger);
            });
        }
        if (Request::is('*/account/journal/*')) {
            Route::bind('journal', function ($journal) {
                return Journal::findorNew($journal);
            });
        }
        if (Request::is('*/account/detail/*')) {
            Route::bind('detail', function ($detail) {
                return Detail::findorNew($detail);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
